==> pot-3.2.1.src.tar.gz: pot-3.2/commun.h <==
/*
pot est un programme servant  lister vos "pot" sur un rseau
Copyright (C) 2001 Fabien Carrion et Guillaume Pinot

Ce programme est libre, vous pouvez le redistribuer et/ou le modifier
selon les termes de la Licence Publique Gnrale GNU publie par la
Free Software Foundation (version 2).

Ce programme est distribu car potentiellement utile, mais SANS AUCUNE
GARANTIE, ni explicite ni implicite, y compris les garanties de
commercialisation ou d'adaptation dans un but
spcifique. Reportez-vous  la Licence Publique Gnrale GNU pour plus
de dtails.

Vous devez avoir reu une copie de la Licence Publique Gnrale GNU en
mme temps que ce programme ; si ce n'est pas le cas, crivez  la
Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
02111-1307, tats-Unis.

fcarrion@etu.utc.fr
pinotgui@etu.utc.fr
*/

#include <unistd.h>
#include <stdio.h>
#include <string.h>
#include <strings.h>
#include <errno.h>
#include <stdlib.h>
#include <utmp.h>
#include <sys/types.h>
#include <fcntl.h>
#include <pwd.h>
#include <locale.h>
#include <sys/stat.h>
#include <wait.h>

#define VERSION "3.2.1"

/* chemin de utmp */
#ifdef __osf__ /* Pour vega... */
#define UTMP "/var/adm/utmp"
#else
#define UTMP "/var/run/utmp"
#endif

/* tty est inscriptible si le mode est 220 */
#define TALKABLE 0220

/* Liste chain des connects */
struct liste_connecte
{
  int talk;
  char *login;
  char *ordi;
  char *nom;
  char *salle;
  struct liste_connecte *next;
  struct liste_connecte *previous;
} *connecte ,  depart;

/* Liste chainee des personnes dans le .pot.pot */
struct liste_pot
{
  char login[9];
  struct liste_pot *next;
};

/* declaration des prototypes */

/* affiche un fichier sur stdout */
void view(char *chemin);

/* supprime un login de ~/.pot.pot */
void suppr(char *chemin,void *optarg);

/* gestion des erreurs  l'ouverture d'un flux */
void erreur(FILE *pipe);

/* remplit la stucture connecte par rapport  localhost, retourne le nombre de connect, -1 si echoue  */
int finger(char *chemin);

/* la fonction rajoute un connecte, 0 quand choue, 1 sinon */
int ajouteliste(char *login , char *ordi , char *tty , struct passwd *ki);

/* la fonction retourne 1 si on peut communiquer avec la personne sinon 0 */
short talkable( char *tty );

/* la fonction scanne les connecte par samba (PC) */
int samba(char *chemin);

/* efface la liste chaine */
int free_liste( void );

/* Verification du login entree : renvoie 0 s il est correct ; -1 ou -2 sinon */
short int verif_login(char *login, int choix,char *chemin,struct liste_pot *premier);

/* fonction chargeant les personnes du .pot.pot dans la liste chainee liste_pot */
struct liste_pot *charge_liste_pot(char *chemin);

/* fonction ajoutant un login dans liste_pot */
struct liste_pot *ajout_liste_pot(char *login, struct liste_pot *premier);

/* fonction retirant un login dans liste_pot */
struct liste_pot *del_liste_pot(char *login, struct liste_pot *premier);

/* fonction pour tout efface */
void suppr_all_liste_pot(struct liste_pot *premier);

/* fonction pour creer un fichier a partir de la liste chainee */
void fichier_liste_pot(char *chemin,struct liste_pot *premier);

==> pot-3.3.0.src.tar.gz: pot-3.3/commun.h <==
/*
pot est un programme servant  lister vos "pot" sur un rseau
Copyright (C) 2001 Fabien Carrion et Guillaume Pinot

Ce programme est libre, vous pouvez le redistribuer et/ou le modifier
selon les termes de la Licence Publique Gnrale GNU publie par la
Free Software Foundation (version 2).

Ce programme est distribu car potentiellement utile, mais SANS AUCUNE
GARANTIE, ni explicite ni implicite, y compris les garanties de
commercialisation ou d'adaptation dans un but
spcifique. Reportez-vous  la Licence Publique Gnrale GNU pour plus
de dtails.

Vous devez avoir reu une copie de la Licence Publique Gnrale GNU en
mme temps que ce programme ; si ce n'est pas le cas, crivez  la
Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
02111-1307, tats-Unis.

fcarrion@etu.utc.fr
pinotgui@etu.utc.fr
*/

#include <unistd.h>
#include <stdio.h>
#include <string.h>
#include <strings.h>
#include <errno.h>
#include <stdlib.h>
#include <utmp.h>
#include <sys/types.h>
#include <fcntl.h>
#include <pwd.h>
#include <locale.h>
#include <sys/stat.h>
#include <wait.h>
#include "readutmp.h"

#define VERSION "3.3.0"

/* chemin de utmp */
#ifdef __osf__ /* Pour vega... */
#  define UTMP "/var/adm/utmp"
#else
#  define UTMP "/var/run/utmp"
#endif

/* tty est inscriptible si le mode est 220 */
#define TALKABLE 0220

/* Liste chain des connects */
struct liste_connecte
{
  int talk;
  char *login;
  char *ordi;
  char *nom;
  char *salle;
  time_t idle; /* -1 si smb */
  struct liste_connecte *next;
  struct liste_connecte *previous;
} *connecte ,  depart;

/* Liste chainee des personnes dans le .pot.pot */
struct liste_pot
{
  char login[9];
  struct liste_pot *next;
};

/* Liste chainee de logins (provenant de .pot.pot ou de la lecture de
   utmp) */
struct liste_utmp
{
  STRUCT_UTMP *description;
  struct liste_utmp *next;
};
   

struct liste_samba
{
  char *login;
  char *ordi;
  struct liste_samba *next;
};

/* declaration des prototypes */

/* affiche un fichier sur stdout */
void view(char *chemin);

/* supprime un login de ~/.pot.pot */
void suppr(char *chemin,void *optarg);

/* gestion des erreurs  l'ouverture d'un flux */
void erreur(FILE *pipe);

/* remplit la structure connecte */
int recherche_pots(char *chemin);

/* remplit la stucture connecte par rapport  localhost, retourne
   le nombre de connect, -1 si echoue */
struct liste_utmp * finger();

/* la fonction rajoute un connecte, 0 quand choue, 1 sinon */
int ajouteliste(char *login , char *ordi , char *tty , struct passwd *ki);

/* la fonction retourne 1 si on peut communiquer avec la personne
   sinon 0 */
short talkable( char *tty );

/* retourne l'idle time, -1 si erreur, -2 si samba, -3 si xdm */
time_t idle_time(char *tty);

#ifdef SAMBA
/* la fonction scanne les connecte par samba (PC) */
struct liste_samba * samba();
#endif


/* efface la liste chaine */
int free_liste( void );

/* Verification du login entree : renvoie 0 s il est correct ; -1 ou
   -2 sinon */
short int verif_login(char *login, int choix,char *chemin,struct liste_pot *premier);

/* fonction chargeant les personnes du .pot.pot dans la liste chainee
   liste_pot */
struct liste_pot *charge_liste_pot(char *chemin);

/* fonction ajoutant un login dans liste_pot */
struct liste_pot *ajout_liste_pot(char *login, struct liste_pot *premier);

/* fonction retirant un login dans liste_pot */
struct liste_pot *del_liste_pot(char *login, struct liste_pot *premier);

/* fonction pour tout efface */
void suppr_all_liste_pot(struct liste_pot *premier);

/* fonction pour creer un fichier a partir de la liste chainee */
void fichier_liste_pot(char *chemin,struct liste_pot *premier);
